@@ -1,5 +1,5 @@
 package Mail::LMLM::Types::Majordomo;
-$Mail::LMLM::Types::Majordomo::VERSION = '0.6805';
+$Mail::LMLM::Types::Majordomo::VERSION = '0.6806';
 use strict;
 use warnings;
 
@@ -7,7 +7,7 @@ use Mail::LMLM::Types::Base;
 
 use vars qw(@ISA);
 
-@ISA=qw(Mail::LMLM::Types::Base);
+@ISA = qw(Mail::LMLM::Types::Base);
 
 sub parse_args
 {
@@ -17,14 +17,14 @@ sub parse_args
 
     $args = $self->SUPER::parse_args($args);
 
-    my (@left, $key, $value);
+    my ( @left, $key, $value );
 
-    while (scalar(@$args))
+    while ( scalar(@$args) )
     {
-        $key = shift(@$args);
+        $key   = shift(@$args);
         $value = shift(@$args);
 
-        if ($key =~ /^-?(owner)$/)
+        if ( $key =~ /^-?(owner)$/ )
         {
             $self->{'owner'} = $value;
         }
@@ -41,34 +41,34 @@ sub _get_post_address
 {
     my $self = shift;
 
-    return ($self->get_group_base(), $self->get_hostname());
+    return ( $self->get_group_base(), $self->get_hostname() );
 }
 
 sub _get_owner_address
 {
     my $self = shift;
 
-    return @{$self->{'owner'}};
+    return @{ $self->{'owner'} };
 }
 
 sub render_mail_management
 {
     my $self = shift;
 
-    my $htmler = shift;
-    my $begin_msg = shift;
+    my $htmler      = shift;
+    my $begin_msg   = shift;
     my $line_prefix = shift;
 
-    $htmler->para($begin_msg . " write a message with the following line as body:");
+    $htmler->para(
+        $begin_msg . " write a message with the following line as body:" );
     $htmler->indent_inc();
-    $htmler->para(($line_prefix. " " . $self->get_group_base()), { 'bold' => 1});
+    $htmler->para( ( $line_prefix . " " . $self->get_group_base() ),
+        { 'bold' => 1 } );
     $htmler->indent_dec();
     $htmler->para("to the following address:");
     $htmler->indent_inc();
     $htmler->start_para();
-    $htmler->email_address(
-        "majordomo", $self->get_hostname()
-        );
+    $htmler->email_address( "majordomo", $self->get_hostname() );
     $htmler->end_para();
     $htmler->indent_dec();
 
@@ -81,11 +81,8 @@ sub render_subscribe
 
     my $htmler = shift;
 
-    return $self->render_mail_management(
-        $htmler,
-        "To subscribe",
-        "subscribe"
-        );
+    return $self->render_mail_management( $htmler, "To subscribe",
+        "subscribe" );
 }
 
 sub render_unsubscribe
@@ -94,11 +91,8 @@ sub render_unsubscribe
 
     my $htmler = shift;
 
-    return $self->render_mail_management(
-        $htmler,
-        "To unsubscribe",
-        "unsubscribe"
-        );
+    return $self->render_mail_management( $htmler, "To unsubscribe",
+        "unsubscribe" );
 }
 
 sub render_post
@@ -107,11 +101,9 @@ sub render_post
 
     my $htmler = shift;
 
-    return $self->render_something_with_email_addr(
-        $htmler,
+    return $self->render_something_with_email_addr( $htmler,
         "Send your messages to the following address: ",
-        \&_get_post_address
-        );
+        \&_get_post_address );
 }
 
 sub render_owner
@@ -120,11 +112,9 @@ sub render_owner
 
     my $htmler = shift;
 
-    return $self->render_something_with_email_addr(
-        $htmler,
+    return $self->render_something_with_email_addr( $htmler,
         "Send messages to the mailing-list owner to the following address: ",
-        \&_get_owner_address
-        );
+        \&_get_owner_address );
 }
 
 1;
@@ -142,11 +132,7 @@ lists.
 
 =head1 VERSION
 
-version 0.6805
-
-=head1 VERSION
-
-version 0.6805
+version 0.6806
 
 =head1 METHODS
 
@@ -188,7 +174,7 @@ unknown
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by unknown.
+This software is Copyright (c) 2019 by unknown.
 
 This is free software, licensed under:
 
@@ -197,7 +183,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/mail-lmlm/issues>
+L<https://github.com/shlomif/perl-mail-lmlm/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -306,8 +292,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<https://github.com/shlomif/mail-lmlm>
+L<https://github.com/shlomif/perl-mail-lmlm>
 
-  git clone http://bitbucket.org/shlomif/perl-mail-lmlm/overview
+  git clone git://github.com/shlomif/perl-mail-lmlm.git
 
 =cut
